@@ -64,6 +64,19 @@ test_cases_for_title_parsing = [
     ("[DIY]官译简繁+简英繁英双语字幕*DTS:X临境音效*", ""),
     ("Lord of Mysteries | 诡秘之主 小丑卷 第10集", "诡秘之主" ),
     ("[Checked by maomao] 在远方 第一季 全54集 | 类型:剧情/爱情 主演:刘烨/马伊琍/梅婷 [国语/中字] | *4K* ", "在远方"),
+    ("[Checked by Ticutme] 鹊刀门传奇 全40集【杜比音效】【主演: 赵本山 | 宋小宝 | 宋晓峰 | 文松 | 程野】QHstudIo小组作品", "鹊刀门传奇"),
+    ("官方国语中字 [2023年9月国漫] 仙逆 第103集", "仙逆"),
+    ("官方国语中字 [短剧] 匿爱 全23集 | 4K 高码 | 国语/中字 | 类型:剧情/爱情/短片 | 主演:施南 | *第15/16集..", "匿爱"),
+    ("【台湾(区)】零日攻击 | 国语中字", "零日攻击"),
+    ("【韩国/南韩】我的完美秘书 | 国语中字", "我的完美秘书"),
+    ("驱魔 / Exorcisms / L‘éventreur de Notre-Dame | 类别：惊悚 恐怖", "驱魔"),
+    ("4K 杜比视界 | 类型: 剧情/惊悚/犯罪 | 导演: 泰勒·派瑞 | 主演: 凯莉·罗兰/崔凡特·罗兹/肖恩·萨加尔/RonReacoLee/凯莉·奥马利", ""), 
+    ("[泰剧] 明星的重生 第一季 全10集 / 巨星重生 / การเกิดใหม่ของดวงดาว / ResetTheSeries |..", "明星的重生"),
+    ("[国漫连载] 我的师兄太强了 / 我的师兄太强了之重见天明篇 / 我的师兄太强了之风起云涌篇 / 我的师兄太强了之拨云见日篇 / 我的师兄太强了之群雄逐鹿篇 / 我的师兄太强了之波云诡谲篇 第48集 4K [bilibili大陆]", "我的师兄太强了"),
+    ("日本沉没 / 日本沉没2020 / 日本沉没：希望之人 / Nihon Chinbotsu 2020 / Japan Sinks: 2020 | 全10集 | 4K HDR10+", "日本沉没"),
+    ("【果宝特攻 第一季 全52集 *部分720p* | 类型：喜剧 动作 动画 儿童 奇幻 冒险 | 主演：王巍 陆双 邓红 祖晴 赵然 *云视听极光*】", "果宝特攻"),
+    ("新·驯龙高手/驯龙记(港) | DiY国粤双语配音 | 官译简繁+简英繁英双语字幕", "新·驯龙高手"),
+    ("港剧: 经典台 雪山飞狐 [粤语/简体字幕]", "雪山飞狐"),
 ]   
 
 
